@@ -25,6 +25,8 @@
 
 #include "pirkeysetmetadata.h"
 
+#include "philips.h" // for generic RC5 keyset
+
 class QObject;
 class QComboBox;
 
@@ -154,6 +156,18 @@ public:
     QObject *guiObject);
 };
 
+
+class GrundigTV5: public PhilipsTV1
+{
+public:
+  GrundigTV5(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+
 class GrundigDVD1: public PIRKeysetMetaData
 {
 public:
